@@ -23,6 +23,8 @@ import xml.etree.ElementTree as ET
 import requests
 import six
 
+from scciclient.irmc import ipmi
+from scciclient.irmc import snmp
 
 DEBUG = False
 
@@ -30,7 +32,7 @@ DEBUG = False
 class SCCIError(Exception):
     """SCCI Error
 
-    This exception is gerenral excetion.
+    This exception is general exception.
     """
     def __init__(self, message, errorcode=None):
         super(SCCIError, self).__init__(message)
@@ -125,7 +127,7 @@ _VIRTUAL_MEDIA_CD_SETTINGS = '''
   <!-- "ConfBmcMediaOptionsCdNumber" -->
   <!-- Number of emulated CDROM/DVD Devices -->
   <CMD Context="SCCI" OC="ConfigSpace" OE="1A68" OI="0" Type="SET">
-    <DATA Type="xsd::integer">2</DATA>
+    <DATA Type="xsd::integer">1</DATA>
   </CMD>
   <!-- "ConfBmcRemoteCdImageServer" -->
   <CMD Context="SCCI" OC="ConfigSpace" OE="1A60" OI="0" Type="SET">
@@ -171,7 +173,7 @@ _VIRTUAL_MEDIA_FD_SETTINGS = '''
   <!-- "ConfBmcMediaOptionsFdNumber" -->
   <!-- Number of emulated FD Devices -->
   <CMD Context="SCCI" OC="ConfigSpace" OE="1A58" OI="0" Type="SET">
-    <DATA Type="xsd::integer">2</DATA>
+    <DATA Type="xsd::integer">1</DATA>
   </CMD>
   <!-- "ConfBmcRemoteFdImageServer" -->
   <CMD Context="SCCI" OC="ConfigSpace" OE="1A50" OI="0" Type="SET">
@@ -284,11 +286,13 @@ def scci_cmd(host, userid, password, cmd, port=443, auth_method='basic',
         result_xml = ET.fromstring(r.text)
         status = result_xml.find("./Value")
         # severity = result_xml.find("./Severity")
+        error = result_xml.find("./Error")
         message = result_xml.find("./Message")
         if not int(status.text) == 0:
             raise SCCIClientError(
                 ('SCCI PROTOCOL ERROR, STATUS CODE = %s, '
-                 'MESSAGE = %s' % (str(status.text), message.text)))
+                 'ERROR = %s, MESSAGE = %s' %
+                 (str(status.text), error.text, message.text)))
         else:
             return r
 
@@ -303,7 +307,7 @@ def get_client(host, userid, password, port=443, auth_method='basic',
                client_timeout=60, **kwargs):
     """get SCCI command partial function
 
-    This function returs SCCI command partial function
+    This function returns SCCI command partial function
     :param host: hostname or IP of iRMC
     :param userid: userid for iRMC with administrator privileges
     :param password: password for userid
@@ -327,7 +331,7 @@ def get_virtual_cd_set_params_cmd(remote_image_server,
                                   remote_image_user_password):
     """get Virtual CD Media Set Parameters Command
 
-    This function returs Virtual CD Media Set Parameters Command
+    This function returns Virtual CD Media Set Parameters Command
     :param remote_image_server: remote image server name or IP
     :param remote_image_user_domain: domain name of remote image server
     :param remote_image_share_type: share type of ShareType
@@ -347,7 +351,7 @@ def get_virtual_cd_set_params_cmd(remote_image_server,
         remote_image_username,
         remote_image_user_password)
 
-    return(cmd)
+    return cmd
 
 
 def get_virtual_fd_set_params_cmd(remote_image_server,
@@ -359,7 +363,7 @@ def get_virtual_fd_set_params_cmd(remote_image_server,
                                   remote_image_user_password):
     """get Virtual FD Media Set Parameters Command
 
-    This function returs Virtual FD Media Set Parameters Command
+    This function returns Virtual FD Media Set Parameters Command
     :param remote_image_server: remote image server name or IP
     :param remote_image_user_domain: domain name of remote image server
     :param remote_image_share_type: share type of ShareType
@@ -378,7 +382,7 @@ def get_virtual_fd_set_params_cmd(remote_image_server,
         remote_image_username,
         remote_image_user_password)
 
-    return(cmd)
+    return cmd
 
 
 def get_report(host, userid, password,
@@ -450,7 +454,7 @@ def get_sensor_data_records(report):
 def get_irmc_version(report):
     """get iRMC version
 
-    This function return iRMC version number
+    This function returns iRMC version number
     :param report: SCCI report element
     :returns: version element of SCCI report, or None
     """
@@ -458,3 +462,82 @@ def get_irmc_version(report):
     version = report.find("./System/ManagementControllers/iRMC")
     # ET.dump(version[0])
     return version
+
+
+def get_essential_properties(report, prop_keys):
+    """get essential properties
+
+    This function returns a dictionary which contains keys as in
+    prop_keys and its values from the report.
+
+    :param report: SCCI report element
+    :param prop_keys: a list of keys for essential properties
+    :returns: a dictionary which contains keys as in
+              prop_keys and its values.
+    """
+    v = {}
+    v['memory_mb'] = int(report.find('./System/Memory/Installed').text)
+    v['local_gb'] = sum(
+        [int(int(size.text) / 1024)
+         for size in report.findall('.//PhysicalDrive/ConfigurableSize')])
+    v['cpus'] = sum([int(cpu.find('./CoreNumber').text)
+                     for cpu in report.find('./System/Processor')
+                     if cpu.find('./CoreNumber') is not None])
+    # v['cpus'] = sum([int(cpu.find('./LogicalCpuNumber').text)
+    #                 for cpu in report.find('./System/Processor')])
+    v['cpu_arch'] = 'x86_64'
+
+    return {k: v[k] for k in prop_keys}
+
+
+def get_capabilities_properties(d_info,
+                                capa_keys,
+                                pci_device_ids,
+                                **kwargs):
+    """get capabilities properties
+
+    This function returns a dictionary which contains keys
+    and their values from the report.
+
+
+    :param d_info: the dictionary of ipmitool parameters for accessing a node.
+    :param capa_keys: a list of keys for additional capabilities properties.
+    :param pci_device_ids: the list of string contains <vendorID>/<deviceID>
+    for GPU.
+    :param kwargs: additional arguments passed to scciclient.
+    :returns: a dictionary which contains keys and their values.
+    """
+
+    snmp_client = snmp.SNMPClient(d_info['irmc_address'],
+                                  d_info['irmc_snmp_port'],
+                                  d_info['irmc_snmp_version'],
+                                  d_info['irmc_snmp_community'],
+                                  d_info['irmc_snmp_security'])
+    try:
+        v = {}
+        if 'rom_firmware_version' in capa_keys:
+            v['rom_firmware_version'] = \
+                snmp.get_bios_firmware_version(snmp_client)
+
+        if 'irmc_firmware_version' in capa_keys:
+            v['irmc_firmware_version'] = \
+                snmp.get_irmc_firmware_version(snmp_client)
+
+        if 'server_model' in capa_keys:
+            v['server_model'] = snmp.get_server_model(snmp_client)
+
+        # Sometime the server started but PCI device list building is
+        # still in progress so system will response error. We have to wait
+        # for some more seconds.
+        if kwargs.get('sleep_flag', False) and 'pci_gpu_devices' in capa_keys:
+            time.sleep(5)
+
+        if 'pci_gpu_devices' in capa_keys:
+            v['pci_gpu_devices'] = ipmi.get_gpu(d_info, pci_device_ids)
+
+        if 'trusted_boot' in capa_keys:
+            v['trusted_boot'] = ipmi.get_tpm_status(d_info)
+
+        return v
+    except (snmp.SNMPFailure, ipmi.IPMIFailure) as err:
+        raise SCCIClientError('Capabilities inspection failed: %s' % err)
