@@ -19,13 +19,13 @@ import os
 import time
 import xml.etree.ElementTree as ET
 
-import fixtures
-import httpretty
 import mock
-import requests
+from requests_mock.contrib import fixture as rm_fixture
 import testtools
 
+from scciclient.irmc import ipmi
 from scciclient.irmc import scci
+from scciclient.irmc import snmp
 
 
 class SCCITestCase(testtools.TestCase):
@@ -37,21 +37,7 @@ class SCCITestCase(testtools.TestCase):
     def setUp(self):
         super(SCCITestCase, self).setUp()
 
-        # httpretty doesn't work if http proxy environment variables are set.
-        #
-        # Replacing entire environment varialbes like the way of fixing
-        # bug #1403046 causes to fail the following test case
-        #
-        # os.environ = dict((k, v) for (k, v) in os.environ.items()
-        #                  if k.lower() not in ('http_proxy', 'https_proxy'))
-        #
-        # FAIL: ironic.tests.test_utils.ExecuteTestCase.
-        #       test_execute_use_standard_locale_no_env_variables
-        #
-        # Therefor 'http_proxy' and/or 'https_proxy should be simply removed
-        # without adding anything.
-        self.useFixture(fixtures.EnvironmentVariable('http_proxy'))
-        self.useFixture(fixtures.EnvironmentVariable('https_proxy'))
+        self.requests_mock = self.useFixture(rm_fixture.Fixture())
 
         with open(os.path.join(
                 os.path.dirname(__file__),
@@ -68,11 +54,22 @@ class SCCITestCase(testtools.TestCase):
         self.irmc_address = '10.124.196.159'
         self.irmc_username = 'admin'
         self.irmc_password = 'admin0'
-        # The port has to be 80 due to httpretty problem
-        # see the following test case, test_httpretty_https_works_ng
         self.irmc_port = 80
         self.irmc_auth_method = 'basic'
         self.irmc_client_timeout = 60
+        self.irmc_info = {'irmc_address': self.irmc_address,
+                          'irmc_username': self.irmc_username,
+                          'irmc_password': self.irmc_password,
+                          'irmc_snmp_port': 161,
+                          'irmc_snmp_version': 'v2c',
+                          'irmc_snmp_community': 'public',
+                          'irmc_snmp_security': None,
+                          'irmc_client_timeout': self.irmc_client_timeout,
+                          'irmc_sensor_method': 'ipmitool',
+                          'irmc_auth_method': self.irmc_auth_method,
+                          'irmc_port': 443,
+                          'irmc_tempdir': "/tmp"
+                          }
 
         self.irmc_remote_image_server = '10.33.110.49'
         self.irmc_remote_image_user_domain = 'example.local'
@@ -82,47 +79,6 @@ class SCCITestCase(testtools.TestCase):
         self.irmc_remote_image_username = 'deployer'
         self.irmc_remote_image_user_password = 'password'
 
-    def tearDown(self):
-        super(SCCITestCase, self).tearDown()
-
-    @httpretty.activate
-    def test_httpretty_http_works_ok(self):
-        """Test case for mocking http
-
-        This test case is derived from HTTPPretty Github site
-        in order to compare the resutl with the following test case,
-        test_httpretty_https_works_ng().
-        see mocking the status code
-            https://github.com/gabrielfalcao/HTTPretty
-        """
-        httpretty.register_uri(httpretty.GET, "http://github.com",
-                               body="here is the mocked body",
-                               status=201)
-
-        r = requests.get('http://github.com')
-        self.assertEqual(r.status_code, 201)
-
-    @testtools.skip("demonstrating httpretty https mocking problem")
-    @httpretty.activate
-    def test_httpretty_https_works_ng(self):
-        """Test case for showing https mocking problem
-
-        Mocking https caused
-        TypeError: 'member_descriptor' object is not callable
-        as of httpretty (0.8.3).
-        see  HTTPretty breaking other URLs #65
-             https://github.com/gabrielfalcao/HTTPretty/issues/65
-        This test case will fail when the problem is fixed.
-        Therefor it is marked as "skip".
-        """
-        httpretty.register_uri(httpretty.GET, "https://github.com",
-                               body="here is the mocked body",
-                               status=201)
-        e = self.assertRaises(TypeError,
-                              requests.get,
-                              'https://github.com', verify=False)
-        self.assertEqual("'member_descriptor' object is not callable", str(e))
-
     def test_get_share_type_ok(self):
         nfs_result = scci.get_share_type("nfs")
         self.assertEqual(scci.ShareType.nfs, nfs_result)
@@ -170,17 +126,14 @@ class SCCITestCase(testtools.TestCase):
                                                   self.irmc_password))
         self.assertEqual('ok', returned_mock_requests_post.return_value)
 
-    @httpretty.activate
     def test_scci_cmd_protocol_http_and_auth_basic_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                        <Status>
+                                            <Value>0</Value>
+                                            <Severity>Information</Severity>
+                                            <Message>No Error</Message>
+                                        </Status>""")
 
         r = scci.scci_cmd(self.irmc_address,
                           self.irmc_username,
@@ -191,17 +144,14 @@ class SCCITestCase(testtools.TestCase):
                           client_timeout=self.irmc_client_timeout)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_scci_cmd_protocol_http_and_auth_digest_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                     <Status>
+                                         <Value>0</Value>
+                                         <Severity>Information</Severity>
+                                         <Message>No Error</Message>
+                                     </Status>""")
 
         auth_digest = 'digest'
         r = scci.scci_cmd(self.irmc_address,
@@ -213,12 +163,10 @@ class SCCITestCase(testtools.TestCase):
                           client_timeout=self.irmc_client_timeout)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_scci_cmd_authentication_failure(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="401 Unauthorized",
-                               status=401)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="401 Unauthorized",
+                                status_code=401)
 
         e = self.assertRaises(scci.SCCIClientError,
                               scci.scci_cmd,
@@ -266,12 +214,10 @@ class SCCITestCase(testtools.TestCase):
                          {'port': self.irmc_port,
                           'auth_method': unknown_auth_method}, str(e))
 
-    @httpretty.activate
     def test_power_on_scci_xml_parse_failed(self):
-        httpretty.register_uri(
-            httpretty.POST,
+        self.requests_mock.post(
             "http://" + self.irmc_address + "/config",
-            body="""<?xml version="1.0" encoding="UTF-8"?>
+            text="""<?xml version="1.0" encoding="UTF-8"?>
             <Status>
             <Value>31</Value>
             <Severity>Error</Severity>
@@ -283,8 +229,7 @@ class SCCITestCase(testtools.TestCase):
             SEQ>  <CMD Context="SCCI" OC=PowerOnCabinet OE="0" OI="0"
             -----------------------------^------------------------------).
             </Error>
-            </Status>""",
-            status=200)
+            </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -300,12 +245,10 @@ class SCCITestCase(testtools.TestCase):
             'not well-formed (invalid token): line 10, column 41',
             str(e))
 
-    @httpretty.activate
     def test_power_on_http_failed(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="anything",
-                               status=302)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="anything",
+                                status_code=302)
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -321,17 +264,14 @@ class SCCITestCase(testtools.TestCase):
             'HTTP PROTOCOL ERROR, STATUS CODE = 302',
             str(e))
 
-    @httpretty.activate
     def test_power_on_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -342,17 +282,14 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.POWER_ON)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_power_off_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -363,17 +300,14 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.POWER_OFF)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_power_cycle_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -384,17 +318,14 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.POWER_CYCLE)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_power_reset_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -405,17 +336,14 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.POWER_RESET)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_power_raise_nmi_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -426,17 +354,14 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.POWER_RAISE_NMI)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_power_soft_off_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -447,12 +372,10 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.POWER_SOFT_OFF)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_power_soft_off_ng(self):
-        httpretty.register_uri(
-            httpretty.POST,
+        self.requests_mock.post(
             "http://" + self.irmc_address + "/config",
-            body="""<?xml version="1.0" encoding="UTF-8"?>
+            text="""<?xml version="1.0" encoding="UTF-8"?>
             <Status>
             <Value>31</Value>
             <Severity>Error</Severity>
@@ -460,8 +383,7 @@ class SCCITestCase(testtools.TestCase):
             """ XML format failed) occurred</Message>
             <Error Context="SCCI" OC="ShutdownRequestCancelled"
              OE="0" OI="0">ServerView Agent not connected</Error>
-            </Status>""",
-            status=200)
+            </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -473,21 +395,19 @@ class SCCITestCase(testtools.TestCase):
                               client,
                               scci.POWER_SOFT_OFF)
         self.assertEqual(
-            'SCCI PROTOCOL ERROR, STATUS CODE = 31, MESSAGE = Error 31'
+            'SCCI PROTOCOL ERROR, STATUS CODE = 31,'
+            ' ERROR = ServerView Agent not connected, MESSAGE = Error 31'
             ' (Import of settings in WinSCU XML format failed) occurred',
             str(e))
 
-    @httpretty.activate
     def test_power_soft_cycle_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -498,12 +418,10 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.POWER_SOFT_CYCLE)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_power_soft_cycle_ng(self):
-        httpretty.register_uri(
-            httpretty.POST,
+        self.requests_mock.post(
             "http://" + self.irmc_address + "/config",
-            body="""<?xml version="1.0" encoding="UTF-8"?>
+            text="""<?xml version="1.0" encoding="UTF-8"?>
             <Status>
             <Value>31</Value>
             <Severity>Error</Severity>
@@ -511,8 +429,7 @@ class SCCITestCase(testtools.TestCase):
             """ XML format failed) occurred</Message>
             <Error Context="SCCI" OC="ShutdownRequestCancelled"
              OE="0" OI="0">ServerView Agent not connected</Error>
-            </Status>""",
-            status=200)
+            </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -524,21 +441,19 @@ class SCCITestCase(testtools.TestCase):
                               client,
                               scci.POWER_SOFT_CYCLE)
         self.assertEqual(
-            'SCCI PROTOCOL ERROR, STATUS CODE = 31, MESSAGE = Error 31'
+            'SCCI PROTOCOL ERROR, STATUS CODE = 31,'
+            ' ERROR = ServerView Agent not connected, MESSAGE = Error 31'
             ' (Import of settings in WinSCU XML format failed) occurred',
             str(e))
 
-    @httpretty.activate
     def test_power_cancel_shutdown_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -549,12 +464,10 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.POWER_CANCEL_SHUTDOWN)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_power_cancel_shutdown_ng(self):
-        httpretty.register_uri(
-            httpretty.POST,
+        self.requests_mock.post(
             "http://" + self.irmc_address + "/config",
-            body="""<?xml version="1.0" encoding="UTF-8"?>
+            text="""<?xml version="1.0" encoding="UTF-8"?>
             <Status>
             <Value>31</Value>
             <Severity>Error</Severity>
@@ -562,8 +475,7 @@ class SCCITestCase(testtools.TestCase):
             """ XML format failed) occurred</Message>
             <Error Context="SCCI" OC="ShutdownRequestCancelled"
              OE="0" OI="0">ServerView Agent not connected</Error>
-            </Status>""",
-            status=200)
+            </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -575,7 +487,8 @@ class SCCITestCase(testtools.TestCase):
                               client,
                               scci.POWER_CANCEL_SHUTDOWN)
         self.assertEqual(
-            'SCCI PROTOCOL ERROR, STATUS CODE = 31, MESSAGE = Error 31'
+            'SCCI PROTOCOL ERROR, STATUS CODE = 31,'
+            ' ERROR = ServerView Agent not connected, MESSAGE = Error 31'
             ' (Import of settings in WinSCU XML format failed) occurred',
             str(e))
 
@@ -595,14 +508,11 @@ class SCCITestCase(testtools.TestCase):
         version = scci.get_irmc_version(self.report_ng_xml)
         self.assertEqual(version, None)
 
-    @httpretty.activate
     def test_get_report_ok(self):
-        httpretty.register_uri(
-            httpretty.GET,
+        self.requests_mock.get(
             "http://" + self.irmc_address + "/report.xml",
-            body=self.report_ok_txt,
-            content_type="application/x-www-form-urlencoded",
-            status=200)
+            text=self.report_ok_txt,
+            headers={'Content-Type': "application/x-www-form-urlencoded"})
 
         root = scci.get_report(self.irmc_address,
                                self.irmc_username,
@@ -616,14 +526,12 @@ class SCCITestCase(testtools.TestCase):
         sensor = scci.get_sensor_data_records(root)
         self.assertEqual(sensor.tag, 'SensorDataRecords')
 
-    @httpretty.activate
     def test_get_report_http_failed(self):
-        httpretty.register_uri(
-            httpretty.GET,
+        self.requests_mock.get(
             "http://" + self.irmc_address + "/report.xml",
-            body=self.report_ok_txt,
-            content_type="application/x-www-form-urlencoded",
-            status=302)
+            text=self.report_ok_txt,
+            headers={'Content-Type': "application/x-www-form-urlencoded"},
+            status_code=302)
 
         e = self.assertRaises(scci.SCCIClientError,
                               scci.get_report,
@@ -638,17 +546,14 @@ class SCCITestCase(testtools.TestCase):
             str(e))
 
     @mock.patch.object(time, 'sleep')
-    @httpretty.activate
     def test_virtual_media_cd_setting_ok(self, sleep_mock):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         cmd = scci.get_virtual_cd_set_params_cmd(
             self.irmc_remote_image_server,
@@ -670,17 +575,14 @@ class SCCITestCase(testtools.TestCase):
         sleep_mock.assert_called_once_with(5)
 
     @mock.patch.object(time, 'sleep')
-    @httpretty.activate
     def test_virtual_media_fd_setting_ok(self, sleep_mock):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         cmd = scci.get_virtual_fd_set_params_cmd(
             self.irmc_remote_image_server,
@@ -701,17 +603,14 @@ class SCCITestCase(testtools.TestCase):
         sleep_mock.assert_called_once_with(5)
 
     @mock.patch.object(time, 'sleep')
-    @httpretty.activate
     def test_mount_cd_ok(self, sleep_mock):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -724,17 +623,14 @@ class SCCITestCase(testtools.TestCase):
         self.assertFalse(sleep_mock.called)
 
     @mock.patch.object(time, 'sleep')
-    @httpretty.activate
     def test_mount_fd_ok(self, sleep_mock):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -746,17 +642,14 @@ class SCCITestCase(testtools.TestCase):
         self.assertEqual(r.status_code, 200)
         self.assertFalse(sleep_mock.called)
 
-    @httpretty.activate
     def test_unmount_cd_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                <Value>0</Value>
+                                <Severity>Information</Severity>
+                                <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -767,17 +660,14 @@ class SCCITestCase(testtools.TestCase):
         r = client(scci.UNMOUNT_CD)
         self.assertEqual(r.status_code, 200)
 
-    @httpretty.activate
     def test_unmount_fd_ok(self):
-        httpretty.register_uri(httpretty.POST,
-                               "http://" + self.irmc_address + "/config",
-                               body="""<?xml version="1.0" encoding="UTF-8"?>
-                               <Status>
-                               <Value>0</Value>
-                               <Severity>Information</Severity>
-                               <Message>No Error</Message>
-                               </Status>""",
-                               status=200)
+        self.requests_mock.post("http://" + self.irmc_address + "/config",
+                                text="""<?xml version="1.0" encoding="UTF-8"?>
+                                <Status>
+                                    <Value>0</Value>
+                                    <Severity>Information</Severity>
+                                    <Message>No Error</Message>
+                                </Status>""")
 
         client = scci.get_client(self.irmc_address,
                                  self.irmc_username,
@@ -787,3 +677,153 @@ class SCCITestCase(testtools.TestCase):
                                  client_timeout=self.irmc_client_timeout)
         r = client(scci.MOUNT_FD)
         self.assertEqual(r.status_code, 200)
+
+    def test_get_essential_properties(self):
+        ESSENTIAL_PROPERTIES_KEYS = {
+            'memory_mb', 'local_gb', 'cpus', 'cpu_arch'}
+        expected = {'memory_mb': 8192,
+                    'local_gb': 185,
+                    'cpus': 16,
+                    'cpu_arch': 'x86_64'}
+
+        result = scci.get_essential_properties(
+            self.report_ok_xml, ESSENTIAL_PROPERTIES_KEYS)
+
+        self.assertEqual(expected, result)
+
+    def test_get_essential_properties_empty_cpu_socket(self):
+        ESSENTIAL_PROPERTIES_KEYS = {
+            'memory_mb', 'local_gb', 'cpus', 'cpu_arch'}
+        expected = {'memory_mb': 8192,
+                    'local_gb': 185,
+                    'cpus': 16,
+                    'cpu_arch': 'x86_64'}
+
+        result = scci.get_essential_properties(
+            self.report_ng_xml, ESSENTIAL_PROPERTIES_KEYS)
+
+        self.assertEqual(expected, result)
+
+    @mock.patch.object(ipmi, 'get_gpu')
+    @mock.patch.object(snmp, 'get_server_model')
+    @mock.patch.object(snmp, 'get_irmc_firmware_version')
+    @mock.patch.object(snmp, 'get_bios_firmware_version')
+    @mock.patch.object(ipmi, 'get_tpm_status')
+    def test_get_capabilities_properties(self,
+                                         tpm_mock,
+                                         bios_mock,
+                                         irmc_mock,
+                                         server_mock,
+                                         gpu_mock):
+        capabilities_properties = {'trusted_boot', 'irmc_firmware_version',
+                                   'rom_firmware_version', 'server_model',
+                                   'pci_gpu_devices'}
+        gpu_ids = ['0x1000/0x0079', '0x2100/0x0080']
+        kwargs = {}
+        kwargs['sleep_flag'] = True
+
+        tpm_mock.return_value = False
+        bios_mock.return_value = 'V4.6.5.4 R1.15.0 for D3099-B1x'
+        irmc_mock.return_value = 'iRMC S4-7.82F'
+        server_mock.return_value = 'TX2540M1F5'
+        gpu_mock.return_value = 1
+
+        expected = {'irmc_firmware_version': 'iRMC S4-7.82F',
+                    'pci_gpu_devices': 1,
+                    'rom_firmware_version': 'V4.6.5.4 R1.15.0 for D3099-B1x',
+                    'server_model': 'TX2540M1F5',
+                    'trusted_boot': False}
+
+        result = scci.get_capabilities_properties(
+            self.irmc_info,
+            capabilities_properties,
+            gpu_ids,
+            **kwargs)
+
+        self.assertEqual(expected, result)
+        tpm_mock.assert_called_once_with(self.irmc_info)
+        bios_mock.assert_called_once_with(mock.ANY)
+        irmc_mock.assert_called_once_with(mock.ANY)
+        server_mock.assert_called_once_with(mock.ANY)
+        gpu_mock.assert_called_once_with(self.irmc_info,
+                                         gpu_ids)
+
+    @mock.patch.object(ipmi, 'get_gpu')
+    @mock.patch.object(snmp, 'get_server_model')
+    @mock.patch.object(snmp, 'get_irmc_firmware_version')
+    @mock.patch.object(snmp, 'get_bios_firmware_version')
+    @mock.patch.object(ipmi, 'get_tpm_status')
+    def test_get_capabilities_properties_blank(self,
+                                               tpm_mock,
+                                               bios_mock,
+                                               irmc_mock,
+                                               server_mock,
+                                               gpu_mock):
+
+        capabilities_properties = {}
+        gpu_ids = ['0x1000/0x0079', '0x2100/0x0080']
+        kwargs = {}
+        kwargs['sleep_flag'] = True
+
+        tpm_mock.return_value = False
+        bios_mock.return_value = 'V4.6.5.4 R1.15.0 for D3099-B1x'
+        irmc_mock.return_value = 'iRMC S4-7.82F'
+        server_mock.return_value = 'TX2540M1F5'
+        gpu_mock.return_value = 1
+
+        expected = {}
+
+        result = scci.get_capabilities_properties(
+            self.irmc_info,
+            capabilities_properties,
+            gpu_ids,
+            **kwargs)
+
+        self.assertEqual(expected, result)
+
+    @mock.patch.object(ipmi, '_send_raw_command')
+    @mock.patch.object(snmp.SNMPClient, 'get')
+    def test_get_capabilities_properties_scci_client_error(self,
+                                                           snmp_mock,
+                                                           ipmiraw_mock):
+        capabilities_properties = {'trusted_boot', 'irmc_firmware_version',
+                                   'rom_firmware_version', 'server_model',
+                                   'pci_gpu_devices'}
+        gpu_ids = ['0x1000/0x0079', '0x2100/0x0080']
+        kwargs = {}
+        kwargs['sleep_flag'] = True
+
+        ipmiraw_mock.return_value = None
+        snmp_mock.side_effect = snmp.SNMPFailure("error")
+
+        e = self.assertRaises(scci.SCCIClientError,
+                              scci.get_capabilities_properties,
+                              self.irmc_info,
+                              capabilities_properties,
+                              gpu_ids,
+                              **kwargs)
+        self.assertEqual('Capabilities inspection failed: SNMP operation \''
+                         'GET BIOS FIRMWARE VERSION\' failed: error', str(e))
+
+    @mock.patch.object(ipmi, 'get_gpu')
+    @mock.patch.object(snmp.SNMPClient, 'get')
+    def test_get_capabilities_properties_scci_client_error_ipmi(self,
+                                                                snmp_mock,
+                                                                ipmi_mock):
+        capabilities_properties = {'trusted_boot', 'irmc_firmware_version',
+                                   'rom_firmware_version', 'server_model',
+                                   'pci_gpu_devices'}
+        gpu_ids = ['0x1000/0x0079', '0x2100/0x0080']
+        kwargs = {}
+        kwargs['sleep_flag'] = True
+
+        ipmi_mock.side_effect = ipmi.IPMIFailure("IPMI error")
+        snmp_mock.return_value = None
+
+        e = self.assertRaises(scci.SCCIClientError,
+                              scci.get_capabilities_properties,
+                              self.irmc_info,
+                              capabilities_properties,
+                              gpu_ids,
+                              **kwargs)
+        self.assertEqual('Capabilities inspection failed: IPMI error', str(e))
